"use strict";
/**
 * Inspired by lastpass + https://github.com/bradtraversy/50projects50days/blob/master/password-generator/script.js
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.generatePassword = void 0;
const RANDOM_FUNCS = {
    lowercase: getRandomLowercase,
    uppercase: getRandomUppercase,
    numbers: getRandomNumber,
    symbols: getRandomSymbol,
};
const EASY_TO_READY_CHARS_LOWERCASE = 'abcdefghijkmnopqrstuvwxyz';
const EASY_TO_READY_CHARS_UPPERCASE = 'ABCDEFGHJKLMNPQRSTUVWXYZ';
const SYMBOLS = '!@#$%^&*(){}[]=<>/,.';
function generatePassword(options) {
    var _a, _b, _c, _d, _e, _f;
    const length = Math.max((_a = options === null || options === void 0 ? void 0 : options.length) !== null && _a !== void 0 ? _a : 0, 6);
    const prefix = (_b = options === null || options === void 0 ? void 0 : options.prefix) !== null && _b !== void 0 ? _b : '';
    const restLength = !prefix ? length : length - prefix.length;
    const maps = {
        uppercase: (_c = options === null || options === void 0 ? void 0 : options.uppercase) !== null && _c !== void 0 ? _c : true,
        lowercase: (_d = options === null || options === void 0 ? void 0 : options.lowercase) !== null && _d !== void 0 ? _d : true,
        numbers: (_e = options === null || options === void 0 ? void 0 : options.numbers) !== null && _e !== void 0 ? _e : true,
        symbols: (_f = options === null || options === void 0 ? void 0 : options.symbols) !== null && _f !== void 0 ? _f : true,
    };
    if (options === null || options === void 0 ? void 0 : options.easyToSay) {
        maps.numbers = false;
        maps.symbols = false;
    }
    const funcs = Object.keys(maps)
        .filter((key) => maps[key])
        .map((key) => RANDOM_FUNCS[key]);
    const res = repeat(restLength, () => {
        const fn = funcs[randomInt(funcs.length)];
        return fn.apply(null, [options === null || options === void 0 ? void 0 : options.easyToRead]);
    });
    return [prefix, res].join('');
}
exports.generatePassword = generatePassword;
exports.default = generatePassword;
function getRandomLowercase(easyToRead = false) {
    if (easyToRead) {
        return EASY_TO_READY_CHARS_LOWERCASE[randomInt(EASY_TO_READY_CHARS_LOWERCASE.length)];
    }
    return String.fromCharCode(randomInt(26, 97));
}
function getRandomUppercase(easyToRead = false) {
    if (easyToRead) {
        return EASY_TO_READY_CHARS_UPPERCASE[randomInt(EASY_TO_READY_CHARS_UPPERCASE.length)];
    }
    return String.fromCharCode(randomInt(26, 65));
}
function getRandomNumber(easyToRead = false) {
    if (easyToRead) {
        return String.fromCharCode(randomInt(9, 1) + 48);
    }
    return String.fromCharCode(randomInt(10, 48));
}
function getRandomSymbol() {
    return SYMBOLS[randomInt(SYMBOLS.length)];
}
function randomInt(max, base = 0) {
    return Math.floor(Math.random() * max) + base;
}
function repeat(length, fn) {
    return new Array(length)
        .fill(0)
        .map(() => fn.call(null))
        .join('');
}
